@@ -1,11 +1,11 @@
-#!/usr/bin/env python
+#!/usr/bin/env python2
 import MySQLdb
 import sys
 import argparse
 import os
 
+import jtutils
 import pcsv.any2csv
-import pcsv.utils
 
 import pydb.utils
 
@@ -42,8 +42,8 @@ class MySQLdb_Engine():
         host = os.environ["MYSQL_HOST"]
         user, passwd = self.read_config()
         return MySQLdb.connect(host=host,user=user,passwd=passwd,db=db)
-        
-            
+
+
 def get_home_directory():
     from os.path import expanduser
     home = expanduser("~")
@@ -52,7 +52,7 @@ def get_home_directory():
 def get_tables():
     df = pcsv.any2csv.csv2df(run("SHOW tables"))
     return [r[0] for r in df.values]
-    
+
 def lookup_table_abbreviation(abbrev):
     table_list = get_tables()
     if abbrev in table_list:
@@ -63,10 +63,10 @@ def lookup_table_abbreviation(abbrev):
             return table
     return None
 
-def run(sql, df=False):
-    return run_list([sql], df=False)
+def run(sql, df=False, params=None):
+    return run_list([sql], df, [params])
 
-def run_list(sql_list, df=False):
+def run_list(sql_list, df=False, params_list=None):
     """
     run sql and return either df of results or a string
     """
@@ -74,8 +74,11 @@ def run_list(sql_list, df=False):
     cursor = db.cursor()
     pid = db.thread_id()
     try:
-        for s in sql_list:
-            cursor.execute(s)
+        for i,s in enumerate(sql_list):
+            if params_list:
+                cursor.execute(s,params_list[i])
+            else:
+                cursor.execute(s)
     except (KeyboardInterrupt, SystemExit):
         new_cursor = MySQLdb_Engine.connect().cursor() #old cursor/connection is unusable
         new_cursor.execute('KILL QUERY ' + str(pid))
@@ -96,7 +99,7 @@ def process_field(f):
         return "NULL"
     else:
         return str(f)
-    
+
 def readCL():
     parser = argparse.ArgumentParser()
     parser.add_argument("-i","--index",action="store_true",help="show indexes on a table")
@@ -111,15 +114,16 @@ def readCL():
     parser.add_argument("-k","--kill")
     parser.add_argument("-t","--table", action="store_true", help="db -t table_name col1 col2... --> frequencies for col1,col2 in table_name")
     parser.add_argument("-w","--where",action="store_true",help="db -w table_name col val --> 'SELECT * FROM table_name WHERE col = val'")
+    parser.add_argument("--key",action="store_true", help="db --key table_name primary_key_value --> 'SELECT * FROM table_name WHERE primary_key = primary_key_value'")
     parser.add_argument("positional",nargs="*")
     args = parser.parse_args()
     if args.top:
         args.show_all = True
-    return args.index, args.describe, args.cat, args.head, args.tail, args.show_all, args.top, args.kill, args.profile, args.where, args.table, args.raw, args.positional
+    return args.index, args.describe, args.cat, args.head, args.tail, args.show_all, args.top, args.kill, args.profile, args.where, args.key, args.table, args.raw, args.positional
 
 def main():
-    index, describe, cat, head, tail, show_all, top, kill, profile, where, freq, raw, pos = readCL()
-    if any([index, describe, cat, head, tail, where, freq]):
+    index, describe, cat, head, tail, show_all, top, kill, profile, where, key, freq, raw, pos = readCL()
+    if any([index, describe, cat, head, tail, where, key, freq]):
         lookup = lookup_table_abbreviation(pos[0])
         if lookup:
             table = lookup
@@ -143,7 +147,11 @@ def main():
         offset = int(cnt) - 10
         out = run("SELECT * FROM {table} LIMIT {offset},10".format(**vars()))
     elif where:
-        out = run("SELECT * FROM {table} WHERE {pos[1]} = '{pos[2]}'".format(**vars()))
+        out = run("SELECT * FROM {table} WHERE {pos[1]} = %s".format(**vars()), params = (pos[2],))
+    elif key:
+        key = run("SHOW INDEX FROM {table} WHERE Key_name = 'PRIMARY'".format(**vars()), df=True)["Column_name"].values[0]
+        # function dbk() { col=$(db -r "SHOW INDEX FROM $1 WHERE Key_name = 'PRIMARY'" | pcsv -c 'Column_name' | pawk -g 'i==1'); db "SELECT * FROM $1 WHERE $col = $2"; }
+        out = run("SELECT * FROM {table} WHERE {key} = %s".format(**vars()), params = (pos[1],))
     elif freq:
         csv = ",".join(pos[1:])
         out = run("SELECT {csv},count(*) FROM {table} GROUP BY {csv}".format(**vars()))
@@ -162,7 +170,7 @@ def main():
         sys.stdout.write(out + "\n")
     else:
         out = pcsv.any2csv.csv2pretty(out,max_field_size)
-        pcsv.utils.lines2less(out.split("\n"))
+        jtutils.lines2less(out.split("\n"))
 
 if __name__ == "__main__":
     main()
